@@ -31,7 +31,7 @@ class LinkedInOAuth2(BaseOAuth2[Dict[str, Any]]):
         )
 
     async def get_id_email(self, token: str) -> Tuple[str, str]:
-        async with httpx.AsyncClient() as client:
+        async with self.get_httpx_client() as client:
             profile_response = await client.get(
                 PROFILE_ENDPOINT,
                 headers={"Authorization": f"Bearer {token}"},
